/* /////////////////////////////////////////////////////////////////////////////
 * File:		token.d
 *
 * Purpose:		String tokenisation
 *
 * Created		15th March 2003
 * Updated:		3rd April 2003
 *
 * Copyright:	Synesis Software Pty Ltd, (c) 2002. All rights reserved.
 *
 * Home:		http://www.synesis.com.au/software
 *
 * ////////////////////////////////////////////////////////////////////////// */



/* ////////////////////////////////////////////////////////////////////////// */

module synsoft.win32.token;

/* ////////////////////////////////////////////////////////////////////////// */

/// Uses the string module
import string;

/* ////////////////////////////////////////////////////////////////////////// */

/// \brief Tokenises a string with a character, optionally eliding blanks and/or zero terminating the tokens
///
/// Tokenises a string with a character, optionally eliding blanks and/or zero terminating the tokens
/// \param source The string to tokenise
/// \param delimiter The character delimiter with which <b>source</b> is tokenised
/// \param bElideBlanks If <b>true</b> any blank tokens are elided from the results; if <b>false</b> they are preserved
/// \param bZeroTerminate If <b>true</b> the token slices are zero terminated for compatibility with C zero-terminated string functions
char[][] tokenise(char[] source, char delimiter, bit bElideBlanks, bit bZeroTerminate);


/// \brief Tokenizes a string with a character, optionally eliding blanks and/or zero terminating the tokens
///
/// Tokenizes a string with a character, optionally eliding blanks and/or zero terminating the tokens
/// \param source The string to tokenize
/// \param delimiter The character delimiter with which <b>source</b> is tokenized
/// \param bElideBlanks If <b>true</b> any blank tokens are elided from the results; if <b>false</b> they are preserved
/// \param bZeroTerminate If <b>true</b> the token slices are zero terminated for compatibility with C zero-terminated string functions
char[][] tokenize(char[] source, char delimiter, bit bElideBlanks, bit bZeroTerminate);


/// \brief Tokenises a string with a string, optionally eliding blanks and/or zero terminating the tokens
///
/// Tokenises a string with a character, optionally eliding blanks and/or zero terminating the tokens
/// \param source The string to tokenise
/// \param delimiter The string delimiter with which <b>source</b> is tokenised
/// \param bElideBlanks If <b>true</b> any blank tokens are elided from the results; if <b>false</b> they are preserved
/// \param bZeroTerminate If <b>true</b> the token slices are zero terminated for compatibility with C zero-terminated string functions
char[][] tokenise(char[] source, char[] delimiter, bit bElideBlanks, bit bZeroTerminate);


/// \brief Tokenizes a string with a string, optionally eliding blanks and/or zero terminating the tokens
///
/// Tokenizes a string with a character, optionally eliding blanks and/or zero terminating the tokens
/// \param source The string to tokenize
/// \param delimiter The string delimiter with which <b>source</b> is tokenized
/// \param bElideBlanks If <b>true</b> any blank tokens are elided from the results; if <b>false</b> they are preserved
/// \param bZeroTerminate If <b>true</b> the token slices are zero terminated for compatibility with C zero-terminated string functions
char[][] tokenize(char[] source, char[] delimiter, bit bElideBlanks, bit bZeroTerminate);


/* ////////////////////////////////////////////////////////////////////////// */
;


/* ////////////////////////////////////////////////////////////////////////// */
